@@ -5,7 +5,7 @@ This library provides tools for creating, manipulating, and executing DAGs
 with strong typing support and a context-manager based interface.
 """
 
-from daggerml.core import Dml, Error, Node, Resource
+from daggerml.core import Dag, Dml, Error, Executable, Node, Resource
 
 try:
     from daggerml.__about__ import __version__
@@ -13,4 +13,4 @@ except ImportError:
     __version__ = "local"
 
 
-__all__ = ("Dml", "Error", "Node", "Resource")
+__all__ = ("Dag", "Dml", "Error", "Executable", "Node", "Resource")
